==> cscec5b-sync-impl-3.0.0-20201223.073406-5-sources.jar: com/ejianc/business/sync/bean/CmSubList.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@TableName("jzpm_cm_sublist")
public class CmSubList {
    private static final long serialVersionUID = 1L;
    //主键
    @TableId(value = "pk_sublist")
    private String pk_sublist;
    @TableId(value = "pk_wbsdef")
    private String	pk_wbsdef;
    @TableId(value = "vlistcode")
    private String  vlistcode;
    @TableId(value = "vlistname")
    private String	vlistname;
    @TableId(value = "biscurrentlist")
    private String biscurrentlist ;
    @TableId(value = "ilistsource")
    private Integer ilistsource;

    @TableId(value = "iattribute")
    private Integer iattribute;

    @TableId(value = "vreserve9")  //oddid
    private String vreserve9;

    @TableId(value = "pk_measdoc")
    private String  pk_measdoc;
    @TableId(value = "vmemo")
    private String  vmemo;
    @TableId(value = "nnum")
    private BigDecimal  nnum; //数量
    @TableId(value = "nprice")
    private BigDecimal  nprice; //单价
    @TableId(value = "ntotaloriginmny")
    private BigDecimal	ntotaloriginmny; //合价 （金额）
    @TableId(value = "nfinishsumnum")
    private BigDecimal	nfinishsumnum; //累计完成量
    @TableId(value = "nfinishsumoriginmny")
    private BigDecimal	nfinishsumoriginmny; //累计完成价
    @TableId(value = "pk_contract")
    private String pk_contract;
   @TableId(value = "ts")
    private String ts;
    @TableId(value = "dr")
    private Integer dr;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getPk_sublist() {
        return pk_sublist;
    }

    public void setPk_sublist(String pk_sublist) {
        this.pk_sublist = pk_sublist;
    }

    public String getPk_wbsdef() {
        return pk_wbsdef;
    }

    public void setPk_wbsdef(String pk_wbsdef) {
        this.pk_wbsdef = pk_wbsdef;
    }

    public String getVlistcode() {
        return vlistcode;
    }

    public void setVlistcode(String vlistcode) {
        this.vlistcode = vlistcode;
    }

    public String getVlistname() {
        return vlistname;
    }

    public void setVlistname(String vlistname) {
        this.vlistname = vlistname;
    }

    public String getBiscurrentlist() {
        return biscurrentlist;
    }

    public void setBiscurrentlist(String biscurrentlist) {
        this.biscurrentlist = biscurrentlist;
    }

    public Integer getIlistsource() {
        return ilistsource;
    }

    public void setIlistsource(Integer ilistsource) {
        this.ilistsource = ilistsource;
    }

    public Integer getIattribute() {
        return iattribute;
    }

    public void setIattribute(Integer iattribute) {
        this.iattribute = iattribute;
    }

    public String getVreserve9() {
        return vreserve9;
    }

    public void setVreserve9(String vreserve9) {
        this.vreserve9 = vreserve9;
    }

    public String getPk_measdoc() {
        return pk_measdoc;
    }

    public void setPk_measdoc(String pk_measdoc) {
        this.pk_measdoc = pk_measdoc;
    }

    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    public BigDecimal getNnum() {
        return nnum;
    }

    public void setNnum(BigDecimal nnum) {
        this.nnum = nnum;
    }

    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }

    public BigDecimal getNtotaloriginmny() {
        return ntotaloriginmny;
    }

    public void setNtotaloriginmny(BigDecimal ntotaloriginmny) {
        this.ntotaloriginmny = ntotaloriginmny;
    }

    public BigDecimal getNfinishsumnum() {
        return nfinishsumnum;
    }

    public void setNfinishsumnum(BigDecimal nfinishsumnum) {
        this.nfinishsumnum = nfinishsumnum;
    }

    public BigDecimal getNfinishsumoriginmny() {
        return nfinishsumoriginmny;
    }

    public void setNfinishsumoriginmny(BigDecimal nfinishsumoriginmny) {
        this.nfinishsumoriginmny = nfinishsumoriginmny;
    }

    public String getPk_contract() {
        return pk_contract;
    }

    public void setPk_contract(String pk_contract) {
        this.pk_contract = pk_contract;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public Integer getDr() {
        return dr;
    }

    public void setDr(Integer dr) {
        this.dr = dr;
    }
}

==> cscec5b-sync-impl-3.0.1-20221227.020801-21-sources.jar: com/ejianc/business/sync/bean/CmSubList.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@TableName("jzpm_cm_sublist")
public class CmSubList {
    private static final long serialVersionUID = 1L;
    //主键
    @TableId(value = "pk_sublist")
    private String pk_sublist;
    @TableId(value = "pk_wbsdef")
    private String	pk_wbsdef;
    @TableId(value = "vlistcode")
    private String  vlistcode;
    @TableId(value = "vlistname")
    private String	vlistname;
    @TableId(value = "biscurrentlist")
    private String biscurrentlist ;
    @TableId(value = "ilistsource")
    private Integer ilistsource;

    @TableId(value = "iattribute")
    private Integer iattribute;

    @TableId(value = "vreserve9")  //oddid
    private String vreserve9;

    @TableId(value = "pk_measdoc")
    private String  pk_measdoc;
    @TableId(value = "vmemo")
    private String  vmemo;
    @TableId(value = "nnum")
    private BigDecimal  nnum; //数量
    @TableId(value = "nprice")
    private BigDecimal  nprice; //单价
    @TableId(value = "ntotaloriginmny")
    private BigDecimal	ntotaloriginmny; //合价 （金额）
    @TableId(value = "nfinishsumnum")
    private BigDecimal	nfinishsumnum; //累计完成量
    @TableId(value = "nfinishsumoriginmny")
    private BigDecimal	nfinishsumoriginmny; //累计完成价
    @TableId(value = "pk_contract")
    private String pk_contract;
    @TableField(el = "pk_amountlist, jdbcType=VARCHAR")
    private String pk_amountlist;// 分录主键
   @TableId(value = "ts")
    private String ts;
    @TableId(value = "dr")
    private Integer dr;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getPk_sublist() {
        return pk_sublist;
    }

    public void setPk_sublist(String pk_sublist) {
        this.pk_sublist = pk_sublist;
    }

    public String getPk_wbsdef() {
        return pk_wbsdef;
    }

    public void setPk_wbsdef(String pk_wbsdef) {
        this.pk_wbsdef = pk_wbsdef;
    }

    public String getVlistcode() {
        return vlistcode;
    }

    public void setVlistcode(String vlistcode) {
        this.vlistcode = vlistcode;
    }

    public String getVlistname() {
        return vlistname;
    }

    public void setVlistname(String vlistname) {
        this.vlistname = vlistname;
    }

    public String getBiscurrentlist() {
        return biscurrentlist;
    }

    public void setBiscurrentlist(String biscurrentlist) {
        this.biscurrentlist = biscurrentlist;
    }

    public Integer getIlistsource() {
        return ilistsource;
    }

    public void setIlistsource(Integer ilistsource) {
        this.ilistsource = ilistsource;
    }

    public Integer getIattribute() {
        return iattribute;
    }

    public void setIattribute(Integer iattribute) {
        this.iattribute = iattribute;
    }

    public String getVreserve9() {
        return vreserve9;
    }

    public void setVreserve9(String vreserve9) {
        this.vreserve9 = vreserve9;
    }

    public String getPk_measdoc() {
        return pk_measdoc;
    }

    public void setPk_measdoc(String pk_measdoc) {
        this.pk_measdoc = pk_measdoc;
    }

    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    public BigDecimal getNnum() {
        return nnum;
    }

    public void setNnum(BigDecimal nnum) {
        this.nnum = nnum;
    }

    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }

    public BigDecimal getNtotaloriginmny() {
        return ntotaloriginmny;
    }

    public void setNtotaloriginmny(BigDecimal ntotaloriginmny) {
        this.ntotaloriginmny = ntotaloriginmny;
    }

    public BigDecimal getNfinishsumnum() {
        return nfinishsumnum;
    }

    public void setNfinishsumnum(BigDecimal nfinishsumnum) {
        this.nfinishsumnum = nfinishsumnum;
    }

    public BigDecimal getNfinishsumoriginmny() {
        return nfinishsumoriginmny;
    }

    public void setNfinishsumoriginmny(BigDecimal nfinishsumoriginmny) {
        this.nfinishsumoriginmny = nfinishsumoriginmny;
    }

    public String getPk_contract() {
        return pk_contract;
    }

    public void setPk_contract(String pk_contract) {
        this.pk_contract = pk_contract;
    }

    public String getPk_amountlist() {
        return pk_amountlist;
    }

    public void setPk_amountlist(String pk_amountlist) {
        this.pk_amountlist = pk_amountlist;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public Integer getDr() {
        return dr;
    }

    public void setDr(Integer dr) {
        this.dr = dr;
    }
}
